/*
 *  Copyright 2016 Google Inc. All Rights Reserved.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package com.google.android.apps.forscience.whistlepunk;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertTrue;

import com.google.android.apps.forscience.whistlepunk.sensorapi.SensorStatusListener;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class RecordingStatusListener implements SensorStatusListener {
    public Map<String, Integer> mostRecentStatuses = new HashMap<>();
    private List<String> mErrors = new ArrayList<>();

    @Override
    public void onSourceStatus(String id, int status) {
        mostRecentStatuses.put(id, status);
    }

    @Override
    public void onSourceError(String id, int error, String errorMessage) {
        mErrors.add(errorMessage);
    }

    public void assertNoErrors() {
        assertTrue("" + mErrors, mErrors.isEmpty());
    }

    public void assertErrors(String... messages) {
        assertEquals(Arrays.asList(messages), mErrors);
    }
}
